@@ -49,6 +49,7 @@ class State(object):
                  student_parts=None, solution_parts=None, 
                  highlight = None,
                  highlighting_disabled = None, messages=None,
+                 force_diagnose = False,
                  **kwargs):
 
         # Set basic fields from kwargs
@@ -57,6 +58,7 @@ class State(object):
         self.student_parts = student_parts
         self.solution_parts = solution_parts
         self.messages = messages if messages else []
+        self.force_diagnose = force_diagnose
 
         # parse code if didn't happen yet
         if not hasattr(self, 'student_tree'):
@@ -194,7 +196,8 @@ class State(object):
                       highlight = highlight,
                       highlighting_disabled = highlighting_disabled,
                       messages = messages,
-                      parent_state = self)
+                      parent_state = self,
+                      force_diagnose=self.force_diagnose)
         return(child)
 
     def update(self, **kwargs):
@@ -212,9 +215,9 @@ class State(object):
             # play it safe (most common)
             return True
 
-    def assert_root(self, fun):
+    def assert_root(self, fun, extra_msg=""):
         if self.parent_state is not None:
-            raise InstructorError("`%s()` should only be called from the root state, `Ex()`." % fun)
+            raise InstructorError("`%s()` should only be called from the root state, `Ex()`. %s" % (fun, extra_msg))
 
     def assert_is(self, klasses, fun, prev_fun):
         if self.__class__.__name__ not in klasses:
