@@ -46,7 +46,7 @@ def state_dec(f):
 class Chain:
     def __init__(self, state):
         self._state = state
-        self._crnt_sct = None
+        self._crnt_sct = None  # last called SCT
         self._waiting_on_call = False
 
     def _double_attr_error(self):
@@ -84,6 +84,9 @@ class Chain:
         return chain
 
 class F(Chain):
+    """
+    Chain with deferred State passing
+    """
     def __init__(self, stack = None):
         self._crnt_sct = None
         self._stack = [] if stack is None else stack
@@ -91,6 +94,7 @@ class F(Chain):
 
     def __call__(self, *args, **kwargs):
         if not self._crnt_sct:
+            # first function in chain
             state = kwargs.get('state') or args[0]
             return reduce(lambda s, f: f(state=s), self._stack, state)
         else:
@@ -99,8 +103,7 @@ class F(Chain):
     
     @classmethod
     def _from_func(cls, f):
-        func_chain = cls()
-        func_chain._stack.append(f)
+        func_chain = cls(stack = [f])
         return func_chain
 
 def Ex(state = None):
