@@ -15,7 +15,10 @@ def wrap_in_module(node):
     return new_node
 
 def assert_ast(state, element, fmt_kwargs):
-    patt = "You are zooming in on the {{part}}, but it is not an AST, so it can't be re-run."
+    patt = "You are zooming in on the {{part}}, but it is not an AST, so it can't be re-run." + \
+        " If this error occurred because of ``check_args()``," + \
+        "you may have to refer to your argument differently, e.g. `['args', 0]` or `['kwargs', 'a']`. " + \
+        "Read https://pythonwhat.readthedocs.io/en/latest/articles/checking_function_calls.html#signatures for more info."
     _err_msg = "SCT fails on solution: "
     _err_msg += state.build_message(patt, fmt_kwargs)
     # element can also be { 'node': AST }
